#!/usr/bin/env bash
function catch() {
  if [ "$1" == 141 ]; then
    exit 0
  else
    exit "$1"
  fi
}

function helm2to3_show {
  echo "helm migration mode is enabled, helmfile WILL NOT RUN while HELM2TO3 is true"
  echo "Backups will be performed when --dry-run is not present"

  echo "DRY RUN: Converting ALL releases to Helm3..."
  for release in $(/usr/local/bin/helm --tiller-namespace="$TILLER_NAMESPACE" ls | grep -v NAME | awk '{print $1}')
  do
    /usr/local/bin/helm3/helm 2to3 convert --dry-run --tiller-ns "$TILLER_NAMESPACE" "$release"
  done

  echo "DRY RUN: Cleaning up after helm2..."
  yes y | /usr/local/bin/helm3/helm 2to3 cleanup --dry-run --release-cleanup --tiller-cleanup --tiller-ns "$TILLER_NAMESPACE"
}

function helm2to3_deploy {
  local date
  date=$(date +%Y%m%d%H%M%S)
  local file="${TILLER_NAMESPACE}-${date}.tgz"

  echo "helm migration mode is enabled, helmfile WILL NOT RUN while HELM2TO3 is true"
  echo "Backing up all Helm releases in ${TILLER_NAMESPACE}..."
  /usr/local/bin/helm backup "${TILLER_NAMESPACE}" --tiller-ns "$TILLER_NAMESPACE" --file "$file"

  echo "Storing backup in S3 ..."
  aws s3 cp "$file" s3://cb-riptide-tf-infra/"${PRODUCT}"/"${APPLICATION}"/helm2to3/"${REGION}"/"${ENV_CATEGORY}"/"${file}"

  echo "Converting ALL releases to Helm3..."
  for release in $(/usr/local/bin/helm --tiller-namespace="$TILLER_NAMESPACE" ls | grep -v NAME | awk '{print $1}')
  do
    /usr/local/bin/helm3/helm 2to3 convert --tiller-ns "$TILLER_NAMESPACE" "$release"
  done

  echo "Cleaning up after helm2..."
  yes y | /usr/local/bin/helm3/helm 2to3 cleanup --release-cleanup --tiller-cleanup --tiller-ns "$TILLER_NAMESPACE"

  echo "Removing tiller RBAC, please escalate any errors to #mosaic-support..."
  kubectl -n "$TILLER_NAMESPACE" delete sa "tiller-${TILLER_NAMESPACE}" || true
  kubectl -n "$TILLER_NAMESPACE" delete role "tiller-${TILLER_NAMESPACE}" || true
  kubectl -n "$TILLER_NAMESPACE" delete rolebinding "tiller-${TILLER_NAMESPACE}-binding" || true
  kubectl -n "$TILLER_NAMESPACE" delete secret tiller-secret || true
}
